@@ -38,7 +38,6 @@
 #include "debugger_m88xx0.h"
 #include "ascii_ctype.h"
 #include "hostcom.h"
-#include "logger.h"
 #include "mainapp.h"
 #include "memdump.h"
 #include "mystring.h"
@@ -139,7 +138,6 @@ Debugger::Init()
 		return false;
 	}
 
-	logger = gMainApp.GetLogger();
 	syncer = GetSyncer();
 
 	try {
@@ -486,9 +484,6 @@ Debugger::EnterPrompt()
 {
 	is_prompt = true;
 
-	// プロンプト中はログをシリアライズ。
-	logger->SetSerialize(true);
-
 	// ブレークポイント到達メッセージがあればここで表示
 	if (bpointmsg.empty() == false) {
 		fprintf(cons, "%s", bpointmsg.c_str());
@@ -525,9 +520,6 @@ Debugger::LeavePrompt(bool trace)
 
 	is_prompt = false;
 
-	// ログを非同期に戻す。
-	logger->SetSerialize(false);
-
 	// 最後に VM スレッドで待機している Exec() を起こす
 	{
 		std::lock_guard<std::mutex> lock(mtx);
@@ -936,6 +928,7 @@ Debugger::ReadBreakpointInst(breakpoint_t& bp)
 	{ "n",		&Debugger::cmd_n,		},
 	{ "nt",		&Debugger::cmd_nt,		},
 	{ "pe",		&Debugger::cmd_pe,		},
+	{ "pf",		&Debugger::cmd_pf,		},
 	{ "q",		&Debugger::cmd_q,		},
 	{ "quit",	&Debugger::cmd_q,		},
 	{ "reset",	&Debugger::cmd_reset,	},
@@ -1081,7 +1074,7 @@ Debugger::HelpListMain = {
 	{ "L",		"Set log level" },
 	{ "m/M",	"Memory dump" },
 	{ "n/nt",	"Step until next instruction (Skip subroutines)" },
-	{ "pe",		"Print exception frame" },
+	{ "pe/pf",	"Print exception frame / floating-point state frame" },
 	{ "quit",	"Quit" },
 	{ "r*",		"Show registers (Type \"hr\" for details)" },
 	{ "reset",	"Reset the VM" },
@@ -1325,6 +1318,13 @@ Debugger::HelpDetails = {
 	omitted, %sp is used.
 	)**" },
 
+	//-----
+	{ "pf", R"**(
+	Command: pf <address>
+
+	Print a floating-point state frame starting with <address>.
+	)**" },
+
 	//-----
 	{ "quit", R"**(
 	Command: quit (or q)
@@ -2804,6 +2804,35 @@ Debugger::cmd_pe()
 	return CmdAct::Stay;
 }
 
+// FSAVE フレームを表示する。
+Debugger::CmdAct
+Debugger::cmd_pf()
+{
+	busaddr saddr;
+
+	if (cmdargs.size() < 2) {
+		fprintf(cons, "Usage: pf <address>\n");
+		return CmdAct::Stay;
+	}
+	if (GetAddr(&saddr, true) == false) {
+		return CmdAct::Stay;
+	}
+
+	// スーパーバイザ、データ空間固定でいいはず。
+	saddr |= BusAddr::SRead;
+	// 今のところ論理アドレスのみ(?)
+	saddr |= BusAddr::Logical;
+
+	// m68k 専用。
+	auto mdm68k = dynamic_cast<DebuggerMD_m680x0 *>(curmd);
+	if (mdm68k) {
+		mdm68k->PrintFPStateFrame(cons, saddr);
+	} else {
+		fprintf(cons, "Not supported.\n");
+	}
+	return CmdAct::Stay;
+}
+
 // デバッガ終了コマンド
 Debugger::CmdAct
 Debugger::cmd_q()
