@@ -739,6 +739,8 @@ DebuggerMD_m680x0::Disassemble(DebuggerMemoryStream& mem)
 std::string
 DebuggerMD_m680x0::ParseInst(const std::string& inst) const
 {
+	if (inst == "frestore")	return "f340:ffc0";
+	if (inst == "fsave")	return "f300:ffc0";
 	if (inst == "nop")		return "4e71";
 	if (inst == "ptestr")	return "f0008200:ffc0e200";
 	if (inst == "ptestw")	return "f0008000:ffc0e200";
@@ -756,20 +758,22 @@ class StackData
 	StackData(DebuggerMemoryStream& mem_)
 		: mem(mem_)
 	{
-		ReadWordUntil(4);
 	}
 
 	// 合計が words [ワード] になるまで追加で読み込む。
 	void ReadWordUntil(size_t words);
+	// 合計が bytes (偶数) [バイト] になるまで追加で読み込む。
+	void ReadByteUntil(size_t bytes);
 
 	// 改行込みで出力。
-	void Print(FILE *out, size_t byteoffset, uint bytes, const char *text) const
-	{
-		fprintf(out, "%s\n", Format(byteoffset, bytes, text).c_str());
-	}
+	void Print(FILE *out, size_t byteoffset, uint bytes) const;
+	void Print(FILE *out, size_t byteoffset, uint bytes,
+		const char *, ...) const __printflike(5, 6);
 
 	// 共通の表示用文字列を作成して返す。戻り値は改行なしの文字列。
-	std::string Format(size_t byteoffset, uint bytes, const char *text) const;
+	std::string Format(size_t byteoffset, uint bytes) const;
+	std::string Format(size_t byteoffset, uint bytes,
+		const char *, ...) const __printflike(4, 5);
 
 	// byteoffset の位置のデータを表示用文字列にする。
 	std::string FormatWord(size_t byteoffset) const;
@@ -784,6 +788,9 @@ class StackData
 	size_t bytesize() const noexcept { return framebuf.size() * 2; }
 
  private:
+	std::string FormatV(size_t byteoffset, uint bytes,
+		const char *, va_list) const __printflike(4, 0);
+
 	DebuggerMemoryStream mem;
 	std::vector<uint32> framebuf {};
 };
@@ -796,20 +803,87 @@ StackData::ReadWordUntil(size_t words)
 	}
 }
 
+void
+StackData::ReadByteUntil(size_t bytes)
+{
+	assert((bytes % 1) == 0);
+	size_t words = bytes / 2;
+	while (framebuf.size() < words) {
+		framebuf.push_back(mem.Read(2));
+	}
+}
+
+// 改行込みで表示する。bytes は 2, 4, 16 のみ。追加情報なし。
+void
+StackData::Print(FILE *out, size_t byteoffset, uint bytes) const
+{
+	fprintf(out, "%s\n", Format(byteoffset, bytes).c_str());
+}
+
+// 改行込みで表示する。bytes は 2, 4, 16 のみ。
+void
+StackData::Print(FILE *out, size_t byteoffset, uint bytes,
+	const char *fmt, ...) const
+{
+	va_list ap;
+
+	assert(bytes == 2 || bytes == 4 || bytes == 16);
+
+	va_start(ap, fmt);
+	fprintf(out, "%s\n", FormatV(byteoffset, bytes, fmt, ap).c_str());
+	va_end(ap);
+}
+
 // 共通の表示用文字列を作成して返す。戻り値は改行なしの文字列。
 std::string
-StackData::Format(size_t byteoffset, uint bytes, const char *text) const
+StackData::Format(size_t byteoffset, uint bytes) const
 {
 	std::string s = string_format("+$%02x: ", (uint)byteoffset);
-
 	if (bytes == 2) {
 		s += FormatWord(byteoffset);
+	} else if (bytes == 4) {
+		s += FormatLong(byteoffset);
 	} else {
 		s += FormatLong(byteoffset);
+		s += ' ';
+		s += FormatLong(byteoffset + 4);
+		s += ' ';
+		s += FormatLong(byteoffset + 8);
+		s += ' ';
+		s += FormatLong(byteoffset + 12);
 	}
-	// text があれば位置合わせした後に表示。
-	if (text) {
-		s += string_format("%*s : %s", 8 - bytes * 2, "", text);
+
+	return s;
+}
+
+// 共通の表示用文字列を作成して返す。戻り値は改行なしの文字列。
+std::string
+StackData::Format(size_t byteoffset, uint bytes, const char *fmt, ...) const
+{
+	std::string str;
+	va_list ap;
+
+	va_start(ap, fmt);
+	str = FormatV(byteoffset, bytes, fmt, ap);
+	va_end(ap);
+
+	return str;
+}
+
+// 共通の表示用文字列を作成して返す。戻り値は改行なしの文字列。
+std::string
+StackData::FormatV(size_t byteoffset, uint bytes,
+	const char *fmt, va_list ap) const
+{
+	std::string s = Format(byteoffset, bytes);
+
+	char text[128];
+	vsnprintf(text, sizeof(text), fmt, ap);
+	if (text[0]) {
+		if (bytes == 2) {
+			s += "    ";
+		}
+		s += string_format(" : %s", text);
 	}
 	return s;
 }
@@ -846,6 +920,7 @@ uint32
 StackData::Word(size_t byteoffset) const
 {
 	size_t wordoffset = byteoffset / 2;
+	assert(wordoffset < framebuf.size());
 	return framebuf[wordoffset];
 }
 
@@ -869,28 +944,17 @@ DebuggerMD_m680x0::PrintExceptionFrame(FILE *out, busaddr addr)
 
 	fprintf(out, "Exception stack at $%08x\n", addr.Addr());
 
-	frame.Print(out, 0, 2, "SR");
-	frame.Print(out, 2, 4, "PC");
-	// +6: Format|Vector
-	uint32 format_vector = frame.Word(6);
-	uint32 format = format_vector >> 12;
-	uint32 vector = (format_vector >> 2) & 0xff;
-	std::string s6 = frame.Format(6, 2, "");
-	s6 += string_format("Format=$%x Vector=$%02x", format, vector);
-	auto vectortable = GetVectorTable();
-	const char *exname = vectortable->GetExceptionName(vector);
-	if (exname) {
-		s6 += " \"";
-		s6 += exname;
-		s6 += '\"';
-	}
-	fprintf(out, "%s\n", s6.c_str());
+	frame.ReadWordUntil(4);
 
 	// ここからフレーム別。
+	uint32 format = frame.Word(6) >> 12;
 	switch (format) {
 	 case 0x0:	// 034 Four word stack
+		PrintExceptionFrame0(out, frame);
+		break;
+
 	 case 0x1:	// 034 Throwaway four word stack
-		// 追加ワードなし。
+		PrintExceptionFrameCommon(out, frame, true);
 		break;
 
 	 case 0x2:	// 034 Six word stack
@@ -921,17 +985,134 @@ DebuggerMD_m680x0::PrintExceptionFrame(FILE *out, busaddr addr)
 	}
 }
 
+// 共通の4ワード目までを表示する。
+bool
+DebuggerMD_m680x0::PrintExceptionFrameCommon(FILE *out,
+	const StackData& frame, bool pc_is_next)
+{
+	// $06: Format|Vector
+	uint32 format_vector = frame.Word(6);
+	uint32 format = format_vector >> 12;
+	std::string s6;
+	if ((int32)format_vector < 0) {
+		s6 += "Format+Vector";
+	} else {
+		uint32 vector = (format_vector >> 2) & 0xff;
+		s6 += string_format("Format=$%x Vector=$%02x", format, vector);
+
+		// ベクタ番号からベクタ名を引いてみる。
+		// Vector=$b は本来 Format=$0 で F ライン例外だが、
+		// Format=$2 Vector=$b なら 68040 の未実装 FP 命令例外なので区別する。
+		const char *exname = NULL;
+		if (format == 2 && vector == 0x0b) {
+			exname = "Unimplemented FP Instruction";
+		} else {
+			auto vectortable = GetVectorTable();
+			exname = vectortable->GetExceptionName(vector);
+		}
+		if (exname) {
+			s6 += " \"";
+			s6 += exname;
+			s6 += '\"';
+		}
+	}
+
+	frame.Print(out, 0, 2, "SR");
+	frame.Print(out, 2, 4, "%sPC", pc_is_next ? "Next ": "");
+	frame.Print(out, 6, 2, "%s", s6.c_str());
+
+	// ここがバスエラーならもう出来ることはない。
+	if ((int32)format_vector < 0) {
+		return false;
+	}
+	return true;
+}
+
+void
+DebuggerMD_m680x0::PrintExceptionFrame0(FILE *out, StackData& frame)
+{
+	// Format$0 の PC は
+	// 種類							PC
+	// ----
+	// ・割り込み					次の命令
+	// ・TRAP#N						次の命令
+	// ・フォーマットエラー			当該命令(RTE/FRESTORE)
+	// ・不当命令					当該命令
+	// ・A/F ライン命令				当該命令
+	// ・特権違反					当該命令
+
+	bool next;
+	uint vector = (frame.Word(0x06) & 0xfff) >> 2;
+	switch (vector) {
+	 case M68K::EXCEP_FORMAT:
+	 case M68K::EXCEP_ILLEGAL:
+	 case M68K::EXCEP_ALINE:
+	 case M68K::EXCEP_FLINE:
+	 case M68K::EXCEP_PRIV:
+		next = false;
+		break;
+	 default:
+		next = true;
+		break;
+	}
+	PrintExceptionFrameCommon(out, frame, next);
+}
+
 void
 DebuggerMD_m680x0::PrintExceptionFrame2(FILE *out, StackData& frame)
 {
+	// Format$2 の PC と Address は
+	// 種類							PC			Address
+	// ----							--			-------
+	// ・CHK/CHK2/TRAP*/			次の命令	例外を起こした命令
+	//   FTRAPcc/Trace/ZeroDiv
+	// ・MMU 構成例外				次の命令	例外を起こした命令
+	// ・040 未実装FP命令			次の命令	FPが計算したEA
+	// ・040 アドレスエラー			当該命令	参照アドレス-1
+
+	bool next;
+	const char *addr;
+	uint vector = (frame.Word(0x06) & 0xfff) >> 2;
+	switch (vector) {
+	 case M68K::EXCEP_ZERODIV:
+	 case M68K::EXCEP_CHK:
+	 case M68K::EXCEP_TRAPV:
+	 case M68K::EXCEP_TRACE:
+	 case M68K::EXCEP_MMU_CONFIG:
+		next = true;
+		addr = "Caused instruction address";
+		break;
+
+	 case M68K::EXCEP_FLINE:	// これは 040 の EXCEP_FP_UNIMPL
+		next = true;
+		addr = "Calculated EA";
+		break;
+
+	 case M68K::EXCEP_ADDRERR:
+		next = false;
+		addr = "Reference Address - 1";
+		break;
+
+	 default:
+		next = false;
+		addr = "?";
+		break;
+	}
+
 	frame.ReadWordUntil(6);
-	frame.Print(out, 0x08, 4, "(Next or this) instruction address");
+	if (PrintExceptionFrameCommon(out, frame, next) == false) {
+		return;
+	}
+	frame.Print(out, 0x08, 4, "%s", addr);
 }
 
 void
 DebuggerMD_m680x0::PrintExceptionFrame3(FILE *out, StackData& frame)
 {
 	frame.ReadWordUntil(6);
+	if (PrintExceptionFrameCommon(out, frame, true) == false) {
+		return;
+	}
 	frame.Print(out, 0x08, 4, "Effective Address");
 }
 
@@ -939,6 +1120,9 @@ void
 DebuggerMD_m680x0::PrintExceptionFrame4(FILE *out, StackData& frame)
 {
 	frame.ReadWordUntil(8);
+	if (PrintExceptionFrameCommon(out, frame, true) == false) {
+		return;
+	}
 	frame.Print(out, 0x08, 4, "Effective Address");
 	frame.Print(out, 0x0c, 4, "PC of Faulted Instruction");
 }
@@ -954,40 +1138,41 @@ DebuggerMD_m680x0::PrintExceptionFrame7(FILE *out, StackData& frame)
 	};
 
 	frame.ReadWordUntil(30);
-
+	if (PrintExceptionFrameCommon(out, frame, true) == false) {
+		return;
+	}
 	frame.Print(out, 0x08, 4, "Effective Address");
 
 	// SSW
-	std::string sswbuf = frame.Format(0x0c, 2, "SSW (");
 	uint16 ssw = frame.Word(0x0c);
-	sswbuf += ((ssw & M68040::SSW_CP)) ?  "CP" :  "--";
-	sswbuf += ((ssw & M68040::SSW_CU)) ? " CU" : " --";
-	sswbuf += ((ssw & M68040::SSW_CT)) ? " CT" : " --";
-	sswbuf += ((ssw & M68040::SSW_CM)) ? " CM" : " --";
-	sswbuf += ((ssw & M68040::SSW_MA)) ? " MA" : " --";
-	sswbuf += ((ssw & M68040::SSW_ATC)) ? " ATC" : " ---";
-	sswbuf += ((ssw & M68040::SSW_LK)) ? " LK" : " --";
-	sswbuf += ((ssw & M68040::SSW_RW)) ? " RW=R" : " RW=W";
-	sswbuf += string_format(" size=%s", sizestr[(ssw >> 5) & 3]);
-	sswbuf += string_format(" TT=%u", (ssw >> 3) & 3);
-	sswbuf += string_format(" TM=%u", ssw & 7);
-	fprintf(out, "%s)\n", sswbuf.c_str());
+	frame.Print(out, 0x0c, 2,
+		"SSW (%s %s %s %s %s %s %s RW=%c size=%s TT=%u TM=%u)",
+		((ssw & M68040::SSW_CP)  ? "CP" : "--"),
+		((ssw & M68040::SSW_CU)  ? "CU" : "--"),
+		((ssw & M68040::SSW_CT)  ? "CT" : "--"),
+		((ssw & M68040::SSW_CM)  ? "CM" : "--"),
+		((ssw & M68040::SSW_MA)  ? "MA" : "--"),
+		((ssw & M68040::SSW_ATC) ? "ATC" : "---"),
+		((ssw & M68040::SSW_LK)  ? "LK" : "--"),
+		((ssw & M68040::SSW_RW)  ? 'R' : 'W'),
+		sizestr[(ssw >> 5) & 3],
+		((ssw >> 3) & 3),
+		(ssw & 7));
 
 	// WB[321]S
 	for (uint i = 0; i < 3; i++) {
 		size_t off = 0x0e + i * 2;
-		std::string wbbuf = frame.Format(off, 2, "");
 		uint16 wbs = frame.Word(off);
-		wbbuf += string_format("WB%u Status (", 3 - i);
+		std::string stbuf;
 		if ((wbs & 0x80)) {
-			wbbuf += "Valid";
-			wbbuf += string_format(" size=%s", sizestr[(wbs >> 5) & 3]);
-			wbbuf += string_format(" TT=%u", (wbs >> 3) & 3);
-			wbbuf += string_format(" TM=%u", wbs & 7);
+			stbuf = "Valid";
+			stbuf += string_format(" size=%s", sizestr[(wbs >> 5) & 3]);
+			stbuf += string_format(" TT=%u", (wbs >> 3) & 3);
+			stbuf += string_format(" TM=%u", wbs & 7);
 		} else {
-			wbbuf += "no pending";
+			stbuf = "no pending";
 		}
-		fprintf(out, "%s)\n", wbbuf.c_str());
+		frame.Print(out, off, 2, "WB%u Status (%s)", 3 - i, stbuf.c_str());
 	}
 
 	frame.Print(out, 0x14, 4, "Fault Address");
@@ -1006,33 +1191,34 @@ void
 DebuggerMD_m680x0::PrintExceptionFrameB(FILE *out, StackData& frame)
 {
 	frame.ReadWordUntil(46);
-
-	frame.Print(out, 0x08, 2, "");	// internal
+	if (PrintExceptionFrameCommon(out, frame, false) == false) {
+		return;
+	}
+	frame.Print(out, 0x08, 2);	// internal
 
 	// SSW
-	std::string sswbuf = frame.Format(0x0a, 2, "SSW (");
 	uint16 ssw = frame.Word(0x0a);
-	sswbuf += ((ssw & M68030::SSW_FC)) ?  "FC" :  "--";
-	sswbuf += ((ssw & M68030::SSW_FB)) ? " FB" : " --";
-	sswbuf += ((ssw & M68030::SSW_RC)) ? " RC" : " --";
-	sswbuf += ((ssw & M68030::SSW_RB)) ? " RB" : " --";
-	sswbuf += ((ssw & M68030::SSW_DF)) ? " DF" : " --";
-	sswbuf += ((ssw & M68030::SSW_RM)) ? " RM" : " --";
-	sswbuf += ((ssw & M68030::SSW_RW)) ? " RW=R" : " RW=W";
-	sswbuf += " size=";
-	sswbuf += "LBW3"[(ssw >> 4) & 3];
-	sswbuf += string_format(" FC=%u", ssw & 7);
-	fprintf(out, "%s)\n", sswbuf.c_str());
+	frame.Print(out, 0x0a, 2,
+		"SSW (%s %s %s %s %s %s RW=%c size=%c FC=%u)",
+		((ssw & M68030::SSW_FC) ? "FC" : "--"),
+		((ssw & M68030::SSW_FB) ? "FB" : "--"),
+		((ssw & M68030::SSW_RC) ? "RC" : "--"),
+		((ssw & M68030::SSW_RB) ? "RB" : "--"),
+		((ssw & M68030::SSW_DF) ? "DF" : "--"),
+		((ssw & M68030::SSW_RM) ? "RM" : "--"),
+		((ssw & M68030::SSW_RW) ? 'R'  : 'W'),
+		"LBW3"[(ssw >> 4) & 3],
+		(ssw & 7));
 
 	frame.Print(out, 0x0c, 2, "Instruction Pipe Stage C");
 	frame.Print(out, 0x0e, 2, "Instruction Pipe Stage B");
 	frame.Print(out, 0x10, 4, "Data Cycle Fault Address");
-	frame.Print(out, 0x14, 4, "");
+	frame.Print(out, 0x14, 4);
 	frame.Print(out, 0x18, 4, "Data Output Buffer");
-	frame.Print(out, 0x1c, 4, "");
-	frame.Print(out, 0x20, 4, "");
+	frame.Print(out, 0x1c, 4);
+	frame.Print(out, 0x20, 4);
 	frame.Print(out, 0x24, 4, "Stage B Address");
-	frame.Print(out, 0x28, 4, "");
+	frame.Print(out, 0x28, 4);
 	frame.Print(out, 0x2c, 4, "Data Input Buffer");
 
 	// 残りは内部データなのでまとめる。
@@ -1049,3 +1235,238 @@ DebuggerMD_m680x0::PrintExceptionFrameB(FILE *out, StackData& frame)
 	}
 	fprintf(out, "\n");
 }
+
+void
+DebuggerMD_m680x0::PrintFPStateFrame(FILE *out, busaddr addr)
+{
+	DebuggerMemoryStream mem(this, addr);
+	StackData frame(mem);
+
+	fprintf(out, "Floating-point state frame at $%08x\n", addr.Addr());
+
+	frame.ReadByteUntil(4);
+
+	// 第1ワードはバージョンと後続の長さ。
+	uint64 w00 = frame.Long(0x00);
+	uint32 ver = (w00 >> 24) & 0xff;
+	uint32 len = (w00 >> 16) & 0xff;
+	// VER LEN	Name
+	// $00 ANY	Null State Frame
+	// ver $18	68881 IDLE
+	// ver $38	68882 IDLE
+	// ver $B4	68881 BUSY
+	// ver $D4	68882 BUSY
+	// $41 $00	68040 IDLE
+	// $41 $30	68040 Unimplemented Instruction
+	// $41 $60	68040 BUSY
+	if (ver == 0x00) {
+		frame.Print(out, 0x00, 4, "Null State Frame");
+	} else {
+		// NULL フレーム以外は残り len バイトある。
+		frame.ReadByteUntil(len + 4);
+
+		if (ver == 0x41) {
+			switch (len) {
+			 case 0x00:
+				frame.Print(out, 0x00, 4, "68040 Idle State Frame");
+				break;
+			 case 0x30:
+				frame.Print(out, 0x00, 4,
+					"68040 Unimplemented Instruction State Frame");
+				PrintFPFrame68040Unimpl(out, frame, 0);
+				break;
+			 case 0x60:
+				frame.Print(out, 0x00, 4, "68040 Busy State Frame");
+				PrintFPFrame68040Busy(out, frame);
+				break;
+			 default:
+				frame.Print(out, 0x00, 4, "68040 Unknown State Frame?");
+				break;
+			}
+		} else {
+			switch (len) {
+			 case 0x18:
+				frame.Print(out, 0x00, 4, "68881 Idle State Frame");
+				PrintFPFrame6888xIdle(out, frame, len);
+				break;
+			 case 0x38:
+				frame.Print(out, 0x00, 4, "68882 Idle State Frame");
+				PrintFPFrame6888xIdle(out, frame, len);
+				break;
+			 case 0xb4:
+				frame.Print(out, 0x00, 4, "68881 Busy State Frame");
+				PrintFPFrame6888xBusy(out, frame, len);
+				break;
+			 case 0xd4:
+				frame.Print(out, 0x00, 4, "68882 Busy State Frame");
+				PrintFPFrame6888xBusy(out, frame, len);
+				break;
+			 default:
+				frame.Print(out, 0x00, 4, "Unknown State Frame?");
+				break;
+			}
+		}
+	}
+}
+
+void
+DebuggerMD_m680x0::PrintFPFrame6888xIdle(FILE *out, StackData& frame,
+	uint32 len)
+{
+	bool is68882 = (len == 0x38);
+
+	frame.Print(out, 0x04, 2, "Command/Condition Register");
+	frame.Print(out, 0x06, 2);
+	uint32 pos = 0x08;
+	if (is68882) {
+		for (; pos < 0x28; pos += 16) {
+			frame.Print(out, pos, 16, "(internal register)");
+		}
+	}
+	for (uint i = 0; i < 12; i += 4) {
+		frame.Print(out, pos, 4, "Exceptional Operand");
+		pos += 4;
+	}
+	frame.Print(out, pos, 4, "Operand Register");
+	pos += 4;
+	frame.Print(out, pos, 4, "BIU Flags");
+}
+
+void
+DebuggerMD_m680x0::PrintFPFrame6888xBusy(FILE *out, StackData& frame,
+	uint32 len)
+{
+	uint pos = 4;
+	uint cnt = len / 16;
+	for (uint i = 0; i < cnt; i++) {
+		frame.Print(out, pos, 16, "(internal register)");
+		pos += 16;
+	}
+	for (; pos < len + 4; pos += 4) {
+		frame.Print(out, pos, 4, "(internal register)");
+	}
+}
+
+// 68040 の未実装命令ステートフレーム。
+// 68040 のビジーフレームからも呼ばれる。base には Unimpl の原点を指定するが
+// +$00 からの4バイト分の表示は呼び出し側の担当。
+void
+DebuggerMD_m680x0::PrintFPFrame68040Unimpl(FILE *out, StackData& frame,
+	uint base)
+{
+	// +$04.L: CMDREG3B
+	uint32 reg3b = frame.Word(base + 0x04);
+	frame.Print(out, base + 0x04, 4, "CMDREG3B=$%03x", reg3b);
+
+	// +$08.L: (reserved)
+	uint16 exc = frame.Word(base + 0x08);
+	frame.Print(out, base + 0x08, 4,
+		"(NMNEXC %s %s %s %s %s) (NMCEXC %s %s %s %s %s)",
+		((exc & 0x0200) ? "UN" : "--"),
+		((exc & 0x0100) ? "SN" : "--"),
+		((exc & 0x0080) ? "OE" : "--"),
+		((exc & 0x0040) ? "OF" : "--"),
+		((exc & 0x0020) ? "UF" : "--"),
+		((exc & 0x0010) ? "UN" : "--"),
+		((exc & 0x0008) ? "SN" : "--"),
+		((exc & 0x0004) ? "OE" : "--"),
+		((exc & 0x0002) ? "OF" : "--"),
+		((exc & 0x0001) ? "UF" : "--"));
+
+	// +$0c.L: STAG...
+	uint32 w0c = frame.Word(base + 0x0c);
+	uint32 stag = (w0c >> 13) & 7;
+	frame.Print(out, base + 0x0c, 4,
+		"STAG=%u%s (E=%u) M66=%u M1=%u M0=%u SBIT=%u",
+		stag, MPU68040Device::GetFPUTagName(stag).c_str(),
+		((w0c & 0x1000) ? 1 : 0),
+		((w0c & 0x0400) ? 1 : 0),
+		((w0c & 0x0200) ? 1 : 0),
+		((w0c & 0x0100) ? 1 : 0),
+		((w0c & 0x0080) ? 1 : 0));
+
+	// +$10.L: CMDREG1B
+	uint32 reg1b = frame.Word(base + 0x10);
+	uint32 opclass = reg1b >> 13;
+	uint32 rx = (reg1b >> 10) & 7;
+	uint32 ry = (reg1b >>  7) & 7;
+	uint32 cmd = reg1b & 0x7f;
+	std::string cmdname = MPU68040Device::GetReg1BName(opclass, rx, cmd);
+	frame.Print(out, base + 0x10, 4,
+		"CMDREG1B=$%04x: OPCLASS=%x Rs=%u Rd=%u CMD=$%02x(%s)",
+		reg1b,
+		opclass, rx, ry,
+		cmd, cmdname.c_str());
+
+	// +$14.L: DTAG...
+	uint32 w14 = frame.Word(base + 0x14);
+	uint32 dtag = (w14 >> 13) & 7;
+	frame.Print(out, base + 0x14, 4,
+		"DTAG=%u%s (FPTEMP15=%u) WBTEMP15=%u",
+		dtag, MPU68040Device::GetFPUTagName(dtag).c_str(),
+		((w14 & 0x1000) ? 1 : 0),
+		((w14 & 0x0010) ? 1 : 0));
+
+	// +$18.L: E1,E3,T
+	uint32 w18 = frame.Word(base + 0x18);
+	frame.Print(out, base + 0x18, 4,
+		"E1=%u E3=%u (S=%u X=%u U=%u) T=%u",
+		((w18 & 0x0400) ? 1 : 0),
+		((w18 & 0x0200) ? 1 : 0),
+		((w18 & 0x0100) ? 1 : 0),
+		((w18 & 0x0080) ? 1 : 0),
+		((w18 & 0x0020) ? 1 : 0),
+		((w18 & 0x0010) ? 1 : 0));
+
+	// +$1C.L: FPTS,FPTE
+	uint32 w1c = frame.Word(base + 0x1c);
+	frame.Print(out, base + 0x1c, 4, "FPTS=%u FPTE=$%04x",
+		((w1c & 0x8000) ? 1 : 0),
+		 (w1c & 0x7fff));
+
+	// +$20.L: FPTM
+	// +$24.L: FPTM
+	frame.Print(out, base + 0x20, 4, "FPTM[63:32]");
+	frame.Print(out, base + 0x24, 4, "FPTM[31:00]");
+
+	// +$28.L: ETS,ETE
+	uint32 w28 = frame.Word(base + 0x28);
+	frame.Print(out, base + 0x28, 4, "ETS=%u ETE=$%04x",
+		((w28 & 0x8000) ? 1 : 0),
+		 (w28 & 0x7fff));
+
+	// +$2C.L: ETM
+	// +$30.L: ETM
+	frame.Print(out, base + 0x2c, 4, "ETM[63:32]");
+	frame.Print(out, base + 0x30, 4, "ETM[31:00]");
+}
+
+void
+DebuggerMD_m680x0::PrintFPFrame68040Busy(FILE *out, StackData& frame)
+{
+	frame.Print(out, 0x04, 4, "(reserved)");
+
+	// $08 CU_SAVEPC
+	uint32 w08 = frame.Word(0x08);
+	frame.Print(out, 0x08, 4, "CU_SAVEPC=$%02x", w08 >> 25);
+
+	frame.Print(out, 0x0c, 4, "(reserved)");
+	frame.Print(out, 0x10, 4, "(reserved)");
+	frame.Print(out, 0x14, 4, "(reserved)");
+
+	// $18 WBT
+	uint32 w18 = frame.Word(0x18);
+	frame.Print(out, 0x18, 4, "WBT S=%u E=$%04x",
+		((w18 & 0x8000) ? 1 : 0),
+		 (w18 & 0x7fff));
+	frame.Print(out, 0x1c, 4, "WBTM[63:32]");
+	frame.Print(out, 0x20, 4, "WBTM[31:00]");
+
+	frame.Print(out, 0x24, 4, "(reserved)");
+	frame.Print(out, 0x28, 4, "FPIARCU");
+	frame.Print(out, 0x2c, 4, "(reserved)");
+	frame.Print(out, 0x30, 4, "(reserved)");
+
+	// これ以降は Unimpl と同じ。
+	PrintFPFrame68040Unimpl(out, frame, 0x30);
+}
