@@ -49,6 +49,9 @@ class DebuggerMD_m680x0 : public DebuggerMD
 
 	void PrintExceptionFrame(FILE *, busaddr) override;
 
+	// 浮動小数点ステートフレームを表示する。
+	void PrintFPStateFrame(FILE *, busaddr);
+
  private:
 	MPU680x0Device *cpu {};	// MPU デバイス
 	m68kreg prev {};		// 前回のレジスタセットのコピー
@@ -68,12 +71,19 @@ class DebuggerMD_m680x0 : public DebuggerMD
 	void ShowRegATC();
 	void ShowRegOther();
 
+	bool PrintExceptionFrameCommon(FILE *, const StackData&, bool);
+	void PrintExceptionFrame0(FILE *, StackData&);
 	void PrintExceptionFrame2(FILE *, StackData&);
 	void PrintExceptionFrame3(FILE *, StackData&);
 	void PrintExceptionFrame4(FILE *, StackData&);
 	void PrintExceptionFrame7(FILE *, StackData&);
 	void PrintExceptionFrameB(FILE *, StackData&);
 
+	void PrintFPFrame6888xIdle(FILE *, StackData&, uint32 len);
+	void PrintFPFrame6888xBusy(FILE *, StackData&, uint32 len);
+	void PrintFPFrame68040Unimpl(FILE *, StackData&, uint base);
+	void PrintFPFrame68040Busy(FILE *, StackData&);
+
 	uint32 so_a7 {};			// ステップアウト判定用
 	uint16 so_sr {};
 };
