@@ -440,7 +440,7 @@ MemdumpMonitor::MemdumpMonitor(uint objid_, int monid_)
 	: inherited(objid_)
 {
 	monitor = gMonitorManager->Regist(monid_, this);
-	monitor->func = ToMonitorCallback(&MemdumpMonitor::MonitorUpdate);
+	monitor->SetCallback(&MemdumpMonitor::MonitorScreen);
 	monitor->SetSize(84, 32);
 }
 
@@ -451,7 +451,7 @@ MemdumpMonitor::~MemdumpMonitor()
 
 // モニタ更新
 void
-MemdumpMonitor::MonitorUpdate(Monitor *, TextScreen& screen)
+MemdumpMonitor::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	DebuggerMemoryStream mem(md, saddr);
 
@@ -465,7 +465,7 @@ MemdumpMonitor::MonitorUpdate(Monitor *, TextScreen& screen)
 	 case M68040TableDesc:
 	 case M68040PageDesc:
 	 case M88200Page:
-		MonitorUpdateMemdump(screen, mem);
+		MonitorScreenMemdump(screen, mem);
 		break;
 
 	 case M68030PageLong:
@@ -475,14 +475,14 @@ MemdumpMonitor::MonitorUpdate(Monitor *, TextScreen& screen)
 	 case M680x0Disasm:
 	 case M88100Disasm:
 	 case HD64180Disasm:
-		MonitorUpdateDisasm(screen, mem);
+		MonitorScreenDisasm(screen, mem);
 		break;
 	}
 }
 
 // モニタ更新 (メモリダンプ、ディスクリプタの場合)
 void
-MemdumpMonitor::MonitorUpdateMemdump(TextScreen& screen,
+MemdumpMonitor::MonitorScreenMemdump(TextScreen& screen,
 	DebuggerMemoryStream& mem)
 {
 	// モニタでは 80桁を超えて必要サイズ確保してあるので
@@ -683,7 +683,7 @@ MemdumpMonitor::Update88200Page(TextScreen& screen, int x, int y,
 
 // モニタ更新 (逆アセンブルの場合)
 void
-MemdumpMonitor::MonitorUpdateDisasm(TextScreen& screen,
+MemdumpMonitor::MonitorScreenDisasm(TextScreen& screen,
 	DebuggerMemoryStream& mem)
 {
 	// モニタでは 80桁を超えて必要サイズ確保してあるので
