@@ -18,6 +18,16 @@
 <div class="main1">
 <dl>
 
+<dt>1.6.5 (2026/01/28)
+<dd><ul>
+<li>vm(Update): LUNA-I, LUNA-88K の互換 PROM をシリアルコンソールに対応。
+ <q>Support serial console on the compatible PROM on LUNA-I and LUNA88K.</q>
+<li>debugger(Update): デバッガとログ出力が標準出力で衝突していた問題を修正。
+ <q>Fix a collision between debugger and log to stdout.</q>
+<li>debugger(New): pf コマンドを実装。
+ <q>Implement "pf" command.</q>
+</ul><p>
+
 <dt>1.6.4 (2025/12/08)
 <dd><ul>
 <li>m68k(Fix): 68040 の SRP/URP のマスクを修正。
