@@ -101,7 +101,7 @@ HostCOMDevice::HostCOMDevice(Device *parent_, int n,
 
 		// モニタは hostcom* のみ必要。
 		monitor = gMonitorManager->Regist(ID_MONITOR_HOSTCOM(n), this);
-		monitor->func = ToMonitorCallback(&HostCOMDevice::MonitorUpdate);
+		monitor->SetCallback(&HostCOMDevice::MonitorScreen);
 		monitor->SetSize(33, 17);
 	}
 }
@@ -420,7 +420,7 @@ HostCOMDevice::GetDriverName()
 
 // モニタ
 void
-HostCOMDevice::MonitorUpdate(Monitor *, TextScreen& screen)
+HostCOMDevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	screen.Clear();
 
@@ -430,7 +430,7 @@ HostCOMDevice::MonitorUpdate(Monitor *, TextScreen& screen)
 		screen.Print(0, 1, "HostCOM Driver: %s",
 			driver->GetDriverName().c_str());
 		// 次の1行はドライバ依存情報
-		driver->MonitorUpdateMD(screen, 2);
+		driver->MonitorScreenMD(screen, 2);
 	}
 
 	int y = 4;
