@@ -11,6 +11,37 @@
 // Logger はモニタを持つため Object から派生しているが、(Object のもう一つの
 // 機能である) ログ出力は出来ない。これは自明。
 
+// また、ログと comdriver_stdio (特にデバッガの出力) が標準出力への出力を
+// 共有するため標準出力側のみここで担当している。
+// 概念としての動作はこんな感じ。
+//
+// 送信側スレッド   :   ログスレッド
+//
+// ログ/標準出力    :
+//     |
+//     +------->| queue |------+
+//                             |     Yes
+//                  :        (ログ?)-------------+
+//                             |                 |
+//                  :          | No      +------------------+
+//                             |         | ログモニタに格納 |
+//                  :          |         +------------------+
+//                             |                 |
+//                  :          |                 v
+//                             |       (ログを標準出力に出力?)
+//                  :          |          |           |
+//                             |          | Yes    No |
+//                  :          +<---------+           |
+//                             |                      |
+//                  :          v                      |
+//                     +----------------+             |
+//                  :  | 標準出力に出力 |             |
+//                     +----------------+             |
+//                  :          |                      |
+//                             +-----------+----------+
+//                  :                      |
+//                                        END
+
 #include "logger.h"
 #include "monitor.h"
 #include "mythread.h"
@@ -23,8 +54,6 @@ Logger::Logger()
 {
 	ClearAlias();
 
-	ReconfigStdout();
-
 	monitor = gMonitorManager->Regist(ID_MONITOR_LOG, this);
 	monitor->SetCallback(&Logger::MonitorScreen);
 	monitor->SetSize(80, 40);	// 初期サイズは適当
@@ -111,42 +140,26 @@ void
 Logger::UseStdout(bool val)
 {
 	use_stdout = val;
-	ReconfigStdout();
-}
-
-// 標準出力をシリアライズするかを設定。
-void
-Logger::SetSerialize(bool val)
-{
-	do_serialize = val;
-	ReconfigStdout();
-}
-
-// UseStdout() と SetSerialize() の下請け。
-void
-Logger::ReconfigStdout()
-{
-	if (use_stdout) {
-		stdout_sender =  do_serialize;
-		stdout_logger = !do_serialize;
-	} else {
-		stdout_sender = false;
-		stdout_logger = false;
-	}
 }
 
 // ログ書き込み。
 // 他スレッドから呼ばれる。
 void
-Logger::Write(const char *str)
+Logger::WriteLog(const char *str)
 {
-	// 同期出力ならここで標準出力に出力。
-	if (__predict_false(stdout_sender)) {
-		puts(str);
-	}
-
 	std::lock_guard<std::mutex> lock(queue_mtx);
-	queue.emplace_back(str);
+	queue.emplace_back(LogMsg::Type::Log, str);
+	request |= REQ_QUEUE;
+	cv.notify_one();
+}
+
+// 標準出力への出力。
+// COMDriverStdio から呼ばれる。
+void
+Logger::WriteStdout(const char *str)
+{
+	std::lock_guard<std::mutex> lock(queue_mtx);
+	queue.emplace_back(LogMsg::Type::Stdout, str);
 	request |= REQ_QUEUE;
 	cv.notify_one();
 }
@@ -157,7 +170,7 @@ Logger::ThreadRun()
 	SetThreadAffinityHint(AffinityClass::Light);
 
 	for (;;) {
-		std::string utf8str;
+		LogMsg msg;
 
 		// 何か起きるまで待つ。
 		{
@@ -173,7 +186,7 @@ Logger::ThreadRun()
 				request = 0;
 				continue;
 			} else {
-				utf8str = queue.front();
+				msg = queue.front();
 				queue.pop_front();
 				if (queue.empty()) {
 					request = 0;
@@ -181,19 +194,32 @@ Logger::ThreadRun()
 			}
 		}
 
-		if (__predict_true(utf8str.empty() == false)) {
-			DoLog(utf8str);
+		if (msg.type == LogMsg::Type::Log) {
+			DoLog(msg.text);
+		} else {
+			DoStdout(msg.text);
 		}
 	}
 }
 
+// 標準出力へ出力。
+void
+Logger::DoStdout(const std::string& text)
+{
+	fputs(text.c_str(), stdout);
+	fflush(stdout);
+}
+
 // 着信処理。
 void
 Logger::DoLog(const std::string& utf8str)
 {
-	// 非同期出力でよければ、ここで標準出力に出力。
-	if (stdout_logger) {
+	if (use_stdout) {
+		// 標準出力にも出力。
+		// 入力のログ文字列に終端の改行はなく、
+		// puts() は stdout に改行を付けて出す。fflush() は念のためくらい。
 		puts(utf8str.c_str());
+		fflush(stdout);
 	}
 
 	// コンバータがなければここで終了 (CLI)。
