@@ -175,7 +175,10 @@ class BitmapRGBX : public BitmapBase
 		int sxN, int sxD, int sxS, int syN, int syD, int syS);
 
 	// RGBX 画像を描画
-	void DrawBitmap(int dx, int dy, const BitmapRGBX& src);
+	void DrawBitmap(int dx, int dy, const BitmapRGBX& src, const Rect& sr);
+	void DrawBitmap(int dx, int dy, const BitmapRGBX& src) {
+		DrawBitmap(dx, dy, src, Rect(0, 0, src.GetWidth(), src.GetHeight()));
+	}
 
 	// RGBX 画像が dr のサイズになるよう拡大縮小して描画
 	void DrawBitmapStretch(const Rect& dr, const BitmapRGBX& src);
