@@ -40,7 +40,7 @@ using int64		= int64_t;
 #include <bsd/bsd.h>
 #endif
 
-#include "myendian.h"
+#include "missing_endian.h"
 
 // For cppcheck...
 #if !defined(__CONCAT)
