@@ -48,12 +48,12 @@ extern std::vector<std::string> string_split(const char *str, int len, char c,
 	int nlimit = 0);
 
 // 文字列 str を文字 c で分割したリストを返す。
-static inline std::vector<std::string> string_split(const char *str, char c,
+inline std::vector<std::string> string_split(const char *str, char c,
 	int nlimit = 0) {
 	return string_split(str, strlen(str), c, nlimit);
 }
 // 文字列 str を文字 c で分割したリストを返す。
-static inline std::vector<std::string> string_split(const std::string& str,
+inline std::vector<std::string> string_split(const std::string& str,
 		char c, int nlimit = 0) {
 	return string_split(str.c_str(), str.size(), c, nlimit);
 }
