@@ -80,7 +80,7 @@ Object::putlogn(const char *fmt, ...) const
 void
 Object::WriteLog(const char *buf) const
 {
-	logger->Write(buf);
+	logger->WriteLog(buf);
 }
 
 // このオブジェクトの ID を文字列にして返す
