@@ -225,7 +225,7 @@ end_perf_func()
 {
 	sw.Stop();
 
-	uint64 usec = sw.Elapsed_nsec() / 1000U;
+	uint64 usec = nsec_to_usec(sw.Elapsed_nsec());
 	printf("%" PRIu64 " times/usec\n", perf_count / usec);
 }
 
