@@ -6,7 +6,7 @@
 
 #pragma once
 
-#include "nono.h"
+#include "header.h"
 
 // 定数。
 struct M88100
