@@ -17,31 +17,38 @@
 // :      6        :          5    :              4:              3:3       0
 //  3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1       0
 // +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-- ... --+
-// |B|         |T|P|         |Size |               |R|     |S|I|D|S| Address |
-// |E|         |S|A|         |     |               |W|     |U| | |U| (32bit) |
+// |B| |C|     |T|P|         |Size |               |R|     |S|I|D|S| Address |
+// |E| |I|     |S|A|         |     |               |W|     |2| | | | (32bit) |
 // +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-- ... --+
+//                                                  7 6 5 4 3 2 1 0
+// BE (BusError, bit63)
+//	アドレス変換時のバスエラー。
 //
-// 32ビット目と35ビット目はどちらも S/U で同じ値を入れる。m68k の FC2 に相当。
-// 33ビット目は D (データ空間)。m68k の FC0 に相当。
-// 34ビット目は I (命令/プログラム空間)。m68k の FC1 に相当。
-// これにより、
-// o 下位 33 ビットで S/U と32ビットアドレスが表現できる。
-// o 下位 35 ビットで FC(順不同) と32ビットアドレスが表現できる。
-// o 上位ワードを >>1 すると下位3ビットが FC2-0 (同順) になる。
+// CI (Cache Inhibit, bit61)
 //
-// 39ビット目は R/W (Read なら 1)。これは SSW で使う。
-// 上位ワードを >>1 して下位 7 ビットを取り出すと SSW (の FC と R/W) になる。
+// TS (Table Searched, bit57)
+//	このアドレスを求めるのにテーブルサーチを行ったら%1。デバッガアクセス用。
 //
-// 48,49,50ビット目は要求バイトサイズ (1 - 4)。
+// PA (Physical Address, bit56)
+//	このアドレスを物理アドレスとする場合は %1 を指定する。
+//	論理アドレスまたは区別が不要な場合は %0 にする。
+//	論理アドレスと物理アドレスの両方を受け取るメモリダンプとかで使う。
 //
-// 63ビット目 (BE) は (アドレス変換時の) バスエラーを示す。
+// Size (bit50-48)
+//	要求バイト数で 1 .. 4 で表す。
 //
-// 以下はデバッガなどで使用する追加のビットで、実行系では使わない。
-// 56ビット目 (PA) はこのアドレスを物理アドレスとする場合は %1 を指定する。
-// 論理アドレスまたは区別が不要な場合は %0 にする。
-// 論理アドレスと物理アドレスの両方を受け取るメモリダンプとかで使う。
-// 57ビット目 (TS: Table Search Result) は、このアドレスを求めるのに
-// テーブルサーチを行った場合は %1。
+// RW (Read/Write, bit39)
+//	Read なら %1。
+//	上位ワードを >>1 して下位7ビットを取り出すと SSW (の FC と RW) になる。
+//
+// S2, I, D, S (bit35-32)
+//	S と S2 はどちらも S/U で同じ値を入れる。
+//	D はデータアクセスなら %1 で、m68030 の FC0 に相当。
+//	I は命令(プログラム)アクセスなら %1 で、m68030 の FC1 に相当。
+//	この並びは
+//	 o 下位 33 ビットで S/U と32ビットアドレスが表現できる。
+//	 o 下位 35 ビットで FC(順不同) と32ビットアドレスが表現できる。
+//	 o 上位ワードを >>1 すると下位3ビットが FC2-0 (同順) になる。
 
 // 定数
 enum class BusAddr : uint64
@@ -71,6 +78,7 @@ enum class BusAddr : uint64
 	Logical			= 0x0000'0000'0000'0000ULL,
 	TableSearched	= 0x0200'0000'0000'0000ULL,
 
+	CInhibit		= 0x2000'0000'0000'0000ULL,
 	BusErr			= 0x8000'0000'0000'0000ULL,
 };
 
@@ -139,6 +147,9 @@ class busaddr
 							{ return (value & (uint64)BusAddr::Physical); }
 	bool IsTableSearched() const noexcept
 							{ return (value & (uint64)BusAddr::TableSearched); }
+	bool IsCInhibit() const noexcept
+							{ return (value & (uint64)BusAddr::CInhibit); }
+	bool IsOK() const noexcept		{ return !IsBusErr(); }
 	bool IsBusErr() const noexcept
 							{ return (value & (uint64)BusAddr::BusErr); }
 
@@ -257,11 +268,18 @@ inline busaddr operator|(const BusAddr& lhs, const busaddr& rhs) {
 // |E|T|                     |     |                               | (32bit) |
 // +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-- ... --+
 //
-// BE (63ビット目) はバスエラー。
-// RT (62ビット目) はリトライ。SPC で使う。
-// 48,49,50ビット目は応答サイズ。デバイスが処理したバイト数を 1 - 4 で返す。
-// ウェイトは [tsec] で設定・取得するが、ここに格納するときは [nsec] にする。
-// XXX あとで Size を移動してから [tsec] に統一するかも。
+// BE (BusError, bit63)
+//	バスエラー。
+//
+// RT (Retry, bit62)
+//	リトライ。SPC で使う。
+//
+// Size (bit50-48)
+//	デバイスが処理したバイト数で、1 .. 4 で表す。
+//
+// Wait (bit47-32)
+//	ウェイトは [tsec] で設定・取得するが、ここに格納するときは [nsec] にする。
+//	XXX あとで Size を移動してから [tsec] に統一するかも。
 
 // 定数
 enum class BusData : uint64
