@@ -17,7 +17,7 @@ LCDDevice::LCDDevice()
 	: inherited(OBJ_LCD)
 {
 	monitor = gMonitorManager->Regist(ID_MONITOR_LCD, this);
-	monitor->func = ToMonitorCallback(&LCDDevice::MonitorUpdate);
+	monitor->SetCallback(&LCDDevice::MonitorScreen);
 	monitor->SetSize(67, 3);
 }
 
@@ -265,7 +265,7 @@ LCDDevice::Peek() const
 }
 
 void
-LCDDevice::MonitorUpdate(Monitor *, TextScreen &screen)
+LCDDevice::MonitorScreen(Monitor *, TextScreen &screen)
 {
 	char buf[17];
 
