@@ -33,8 +33,8 @@ class X68kMainbus final : public MainbusDevice
 	bool Poke1(uint32 addr, uint32 data) override;
 
  private:
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
-	DECLARE_MONITOR_CALLBACK(MonitorUpdateAccStat);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
+	DECLARE_MONITOR_SCREEN(MonitorScreenAccStat);
 
 	inline bool IsIntio(uint32) const;
 
