@@ -687,7 +687,7 @@ MFPDevice::gpipname[] = {
 
 // TxCR の設定値から分周期間というかメインカウンタ1回分の時間を返す
 /*static*/ const uint64
-MFPDevice::prescale_ns[8] = {
+MFPDevice::prescale_tsec[8] = {
 	0,
 	1000_nsec,	// /4
 	2500_nsec,	// /10
@@ -778,7 +778,7 @@ MFPDevice::SetTCR(int ch, uint32 data)
 			// ここで TDR を確定させる。
 			// タイマー動作中の TDR の参照はイベント開始時刻から求めていたが
 			// イベントを停止すると求められなくなるので、停止前に求めておく。
-			uint64 period = prescale_ns[prev];
+			uint64 period = prescale_tsec[prev];
 			uint64 now = scheduler->GetVirtTime();
 			mfp.timer[ch].tdr = timer.GetCounter(now, period);
 
@@ -798,7 +798,7 @@ MFPDevice::SetTCR(int ch, uint32 data)
 		// タイマー開始時は TDR はリロードしない。
 		// 割り込みを上げる必要がある時だけイベントを使う。
 
-		uint64 period = prescale_ns[data];
+		uint64 period = prescale_tsec[data];
 		uint64 now = scheduler->GetVirtTime();
 		timer.start = now;
 		if (IsTimerIntrEnable(ch)) {
@@ -819,11 +819,10 @@ MFPDevice::SetTCR(int ch, uint32 data)
 			event[ch]->SetName(string_format("MFP Timer-%c FreeRun", ch + 'A'));
 		}
 
-		putlog(1, "Timer-%c Start Delay mode(%u x %u.%uusec)",
+		putlog(1, "Timer-%c Start Delay mode(%u x %.1fusec)",
 			ch + 'A',
 			timer.tdr,
-			(uint)period / 1000,
-			(uint)(period / 100) % 10);
+			(double)period / 1_usec);
 		return;
 
 	} else if (data == 8) {
@@ -858,7 +857,7 @@ MFPDevice::GetTDR(int ch) const
 		// ディレイモード動作中なら現在値は保持していないので、算出する。
 		// XXX sync_rt == true で割り込み有効にしているタイマーの
 		//     TDR を読み出しても割り込みと整合しないがもう仕方ない。
-		uint64 period = prescale_ns[timer.tcr];
+		uint64 period = prescale_tsec[timer.tcr];
 		uint64 now = scheduler->GetVirtTime();
 		return timer.GetCounter(now, period);
 
@@ -914,7 +913,7 @@ MFPDevice::TimerCallback(Event *ev)
 		timer.tdr = timer.next_tdr;
 		timer.start = 0;
 		// TDR (のリロード値) が変わったのでタイマー周りも再設定。
-		uint64 period = prescale_ns[timer.tcr];
+		uint64 period = prescale_tsec[timer.tcr];
 		ev->time = period * timer.tdr;
 		if (sync_rt) {
 			rt_period[ch] = ev->time;
@@ -958,7 +957,7 @@ MFPDevice::RestartTimerEvent(int ch)
 	assert(timer.start != 0);
 
 	uint64 now = scheduler->GetVirtTime();
-	uint64 period = prescale_ns[timer.tcr];
+	uint64 period = prescale_tsec[timer.tcr];
 	uint64 timeout = period * timer.tdr;
 	event[ch]->time = timeout - ((now - timer.start) % timeout);
 	scheduler->RestartEvent(event[ch]);
