@@ -196,6 +196,6 @@ class MK48T02Device : public RTCDevice
 	Monitor *monitor {};
 };
 
-static inline MK48T02Device *GetMK48T02Device() {
+inline MK48T02Device *GetMK48T02Device() {
 	return Object::GetObject<MK48T02Device>(OBJ_RTC);
 }
