@@ -761,9 +761,9 @@ MPU68030Device::MonitorScreenMMU(TextScreen& screen, int y, m68kreg& tmp)
 void
 MPU68030Device::MonitorScreenATC(Monitor *, TextScreen& screen)
 {
-	screen.Clear();
+	TA e_attr = mmu_tc.e ? TA::Normal : TA::Disable;
 
-	bool atc_enable = mmu_tc.e;
+	screen.Clear();
 
 #if defined(M68030_CUSTOM_ATC)
 	m68030ATCTable_Custom *table;
@@ -783,7 +783,7 @@ MPU68030Device::MonitorScreenATC(Monitor *, TextScreen& screen)
 		int fc = fclist[t].fc;
 		const char *name = fclist[t].name;
 
-		table = atc.fctables[fc];
+		table = atc.GetTable(fc);
 		screen.Print(x, 0, "FC=%u %s", fc, name);
 		screen.Puts(x, 1, "No.  LAddr    PAddr    Flag");
 
@@ -798,15 +798,15 @@ MPU68030Device::MonitorScreenATC(Monitor *, TextScreen& screen)
 		for (uint i = 0; i < m68030ATCTable::LINES; i++) {
 			int idx = sbuf[i * 2 + 1];
 			m68030ATCLine& a = table->line[idx];
-			TA attr;
-			if (a.IsInvalid() || (atc_enable == false)) {
-				attr = TA::Disable;
+			TA v_attr;
+			if (a.IsInvalid()) {
+				v_attr = TA::Disable;
 			} else {
-				attr = TA::Normal;
+				v_attr = TA::Normal;
 			}
 
-			screen.Print(x, i + 2, attr, "[%02x] %08x %08x %c%c%c%c",
-				idx,
+			screen.Print(x,     i + 2, e_attr, "[%02x]", idx);
+			screen.Print(x + 5, i + 2, v_attr, "%08x %08x %c%c%c%c",
 				a.GetLAddr(),
 				a.GetPAddr(),
 				a.IsBusError() ? 'B' : '-',
@@ -822,39 +822,41 @@ MPU68030Device::MonitorScreenATC(Monitor *, TextScreen& screen)
 		bool tt_once_hit;
 
 		{
-			std::lock_guard<std::mutex> lock(table->atchist_mtx);
-			for (int i = 0; i < table->atchist.Length(); i++) {
-				const auto& s = table->atchist.Peek(i);
+			std::lock_guard<std::mutex> lock(table->hist_mtx);
+			for (int i = 0; i < table->hist.Length(); i++) {
+				const auto& s = table->hist.Peek(i);
 				total += s.total;
 				tthit += s.tthit;
 				miss  += s.miss;
 			}
-			tt_once_hit = table->atchist_tt_once_hit;
+			tt_once_hit = table->hist_tt_once_hit;
 		}
 
 		int y = m68030ATCTable::LINES + 2;
-		screen.Puts(x + 1, y, "TT Match");
+		screen.Puts(x + 1, y, e_attr, "TT Match");
 		if (tt_once_hit) {
-			screen.Print(x + 10, y, "%5.1f%%", (double)(tthit * 100) / total);
+			screen.Print(x + 10, y, e_attr, "%5.1f%%",
+				(double)(tthit * 100) / total);
 		} else {
-			screen.Puts(x + 12, y, "0");
+			screen.Puts(x + 12, y, e_attr, "0");
 		}
 		y++;
 
-		screen.Puts(x + 1, y, "ATC Match");
+		screen.Puts(x + 1, y, e_attr, "ATC Match");
 		if (total == 0) {
-			screen.Puts(x + 12, y, "0");
+			screen.Puts(x + 12, y, e_attr, "0");
 		} else {
-			screen.Print(x + 10, y, "%5.1f%%",
+			screen.Print(x + 10, y, e_attr, "%5.1f%%",
 				(double)((total - miss - tthit) * 100) / total);
 		}
 		y++;
 
-		screen.Puts(x + 1, y, "ATC Miss");
+		screen.Puts(x + 1, y, e_attr, "ATC Miss");
 		if (miss == 0) {
-			screen.Puts(x + 12, y, "0");
+			screen.Puts(x + 12, y, e_attr, "0");
 		} else {
-			screen.Print(x + 10, y, "%5.1f%%", (double)(miss * 100) / total);
+			screen.Print(x + 10, y, e_attr, "%5.1f%%",
+				(double)(miss * 100) / total);
 		}
 		y++;
 	}
@@ -864,43 +866,24 @@ MPU68030Device::MonitorScreenATC(Monitor *, TextScreen& screen)
 		"This ATC with FC-separated %u-entries is by nono.",
 		m68030ATCTable::LINES);
 #else
-	m68030ATCTable_Motorola *table = atc.table.get();
-	static const char fcstr[] =
-		"--\0\0"	// 0
-		"UD\0\0"	// 1
-		"UP\0\0"	// 2
-		"--\0\0"	// 3
-		"--\0\0"	// 4
-		"SD\0\0"	// 5
-		"SP\0\0"	// 6
-		"--";		// 7
-
 	//                 00 [00] SD(5).01234'567 01234'567 ----
 	screen.Puts(0, 0, "No Idx  FC    LAddr     PAddr     Flag   Hit%");
 	uint y = 1;
-#if defined(ATC_ORDER128)
-	uint128 order_ = table->order;
-#endif
-	for (uint i = 0; i < m68030ATCTable::LINES; i++) {
-#if defined(ATC_ORDER128)
-		uint n = (uint)order_ & 0x1f;
-		order_ >>= 5;
-#else
-		uint n = table->order[i];
-#endif
-		const m68030ATCLine *a = &table->line[n];
+	auto table = atc.GetTable();
+	for (uint pri = 0; pri < m68030ATCTable::LINES; pri++) {
+		uint idx = table->GetIdx(pri);
+		const m68030ATCLine *a = &table->line[idx];
 		TA attr;
-		if (a->IsInvalid() || (atc_enable == false)) {
+		if (a->IsInvalid()) {
 			attr = TA::Disable;
 		} else {
 			attr = TA::Normal;
 		}
 		uint fc = a->GetFC();
-		screen.Print(0, y++, attr,
-			"%2d [%02d] %u(%s).%06x'00 %06x'00 %c%c%c%c",
-			i,
-			n,
-			fc, &fcstr[fc * 4],
+		screen.Print(0, y, e_attr, "%2d [%02d]", pri, idx);
+		screen.Print(8, y++, attr,
+			"%u(%s).%06x'00 %06x'00 %c%c%c%c",
+			fc, FCstr(fc),
 			(a->GetLAddr() >> 8),
 			(a->GetPAddr() >> 8),
 			(a->IsBusError() ? 'B' : '-'),
@@ -909,26 +892,26 @@ MPU68030Device::MonitorScreenATC(Monitor *, TextScreen& screen)
 			(a->IsModified() ? 'M' : '-'));
 	}
 
-	// ATC ヒット/ミス率、ついでに TT のマッチ率も表示。
-	std::array<double, m68030ATCTable::LINES + 1> rate {};
-	double ttrate {};
-	// total は ATC を検索した回数。
-	uint64 total = table->atcstat.total - table->atcstat.tthit;
+	// ATC ヒット/ミス率。
+	m68030ATCStat tmp = table->stat;
+	std::array<float, m68030ATCTable::LINES> hitrate {};
+	float missrate = 0;
+	// total はヒットとミスの合計。
+	uint64 total = tmp.miss;
+	for (auto v : tmp.hit) {
+		total += v;
+	}
 	if (total != 0) {
-		uint i;
-		for (i = 0; i < m68030ATCTable::LINES; i++) {
-			rate[i] = (double)table->stat_atchit[i] / total * 100;
+		for (uint i = 0; i < hitrate.size(); i++) {
+			hitrate[i] = (float)tmp.hit[i] / total * 100;
 		}
-		rate[i] = (double)table->atcstat.miss / total * 100;
-		ttrate = (double)table->atcstat.tthit / total * 100;
+		missrate = (float)tmp.miss / total * 100;
 	}
 	y = 1;
-	for (auto r : rate) {
-		screen.Print(38, y++, "%6.2f%%", r);
+	for (auto r : hitrate) {
+		screen.Print(38, y++, e_attr, "%6.2f%%", r);
 	}
-	y--;
-	screen.Print(15, y, "(TT Hit:%5.2f%%)", ttrate);
-	screen.Puts(31,  y, "ATCMiss");
+	screen.Print(31, y, e_attr, "ATCMiss%6.2f%%", missrate);
 #endif
 }
 
@@ -936,29 +919,8 @@ MPU68030Device::MonitorScreenATC(Monitor *, TextScreen& screen)
 void
 MPU68030Device::CalcStat()
 {
-#if defined(M68030_CUSTOM_ATC)
 	// ATC のヒット率。
-	for (auto& table : atc.tables) {
-		// ここはロックなしでやってしまう
-		m68030ATCStat s;
-		s.total = table->atcstat.total;
-		s.tthit = table->atcstat.tthit;
-		s.miss  = table->atcstat.miss;
-		table->atcstat.total = 0;
-		table->atcstat.tthit = 0;
-		table->atcstat.miss  = 0;
-
-		// こっちはロックする
-		{
-			std::lock_guard<std::mutex> lock(table->atchist_mtx);
-
-			table->atchist.EnqueueForce(s);
-			if (__predict_false(s.tthit != 0)) {
-				table->atchist_tt_once_hit = true;
-			}
-		}
-	}
-#endif
+	atc.CalcStat();
 
 	// キャッシュのヒット率。
 	icache->CalcStat();
@@ -1046,6 +1008,17 @@ MPU68030Device::MonitorScreenCache1(TextScreen& screen, int y,
 	return y;
 }
 
+/*static*/ const char
+MPU68030Device::fcstr[] =
+	"--\0\0"	// 0
+	"UD\0\0"	// 1
+	"UP\0\0"	// 2
+	"--\0\0"	// 3
+	"--\0\0"	// 4
+	"SD\0\0"	// 5
+	"SP\0\0"	// 6
+	"--";		// 7
+
 
 //
 // 68040
