@@ -47,8 +47,7 @@ class MPU88xx0Device : public MainMPUDevice, private M88100
 	// 割り込みが許可なら true
 	bool IsIntrEnable() const	{ return (reg.psr & PSR_IND) == 0; }
 
-	// 現在アクセス中の論理アドレス、物理アドレスを取得。
-	uint32 GetLaddr() const override;
+	// 現在アクセス中の物理アドレスを取得。
 	uint32 GetPaddr() const override;
 
 	// アクセスウェイト [clock] を加算。m88200 が呼ぶ。
