@@ -216,7 +216,7 @@ NewsCtlrDevice::Peek1(uint32 addr)
 
 // NewsIO の下請けとして呼ばれる。
 void
-NewsCtlrDevice::MonitorUpdateNewsCtlr(TextScreen& screen, int y)
+NewsCtlrDevice::MonitorScreenNewsCtlr(TextScreen& screen, int y)
 {
 	// テーブル方式ではないので、Read/Write と手動で揃える…。
 
