@@ -115,7 +115,7 @@ OPMDevice::WritePort(uint32 offset, uint32 data)
 		// 時刻の起点は CPU 側の命令によって異なるはずだが
 		// わからないので命令のぶんは無視しておく。
 		// 53 クロックのウェイトのほうは足す。
-		busy_origin = now + 53 * mpu->GetClock_nsec();
+		busy_origin = now + 53 * mpu->GetClock_tsec();
 
 		// busy_start のほうはとりあえず 10 クロックにしておく。
 		busy_start = busy_origin + 10 * clk;
