@@ -103,6 +103,6 @@ class PlaneVRAMDevice : public IODevice
 	int yscroll {};
 };
 
-static inline PlaneVRAMDevice *GetPlaneVRAMDevice() {
+inline PlaneVRAMDevice *GetPlaneVRAMDevice() {
 	return Object::GetObject<PlaneVRAMDevice>(OBJ_PLANEVRAM);
 }
