@@ -126,7 +126,7 @@ PowerDevice::DoPowerOn()
 		}
 
 		// 動作モード変更
-		syncer->RequestPowerOffMode(false);
+		syncer->NotifyPowerOffMode(false);
 	}
 }
 
@@ -168,7 +168,7 @@ PowerDevice::DoPowerOff(MessageID msgid)
 		ispower = false;
 
 		// 動作モード変更
-		syncer->RequestPowerOffMode(true);
+		syncer->NotifyPowerOffMode(true);
 	}
 
 	// 電源オフ後の動作は引数によって異なる
