@@ -140,11 +140,11 @@ Luna1PROMEmuDevice::Init()
 	roms.Write4(ROMIO_CLKCNT);
 	roms.Write2(0x4e73);		//	rte
 
-	// Lv6 (SIO) 割り込みハンドラ
-	// キーボード割り込みが上がったら KEYIN をコールする
+	// Lv6 (SIO) 割り込みハンドラ。
+	// この中でコマンドなどを処理する。
 	roms.SetOffset(0x600);
-	roms.Write2(0x4ab9);		//	tst.l	(ROMIO_KEYIN)
-	roms.Write4(ROMIO_KEYIN);	//					; キー入力処理
+	roms.Write2(0x4ab9);		//	tst.l	(ROMIO_SIOINTR)
+	roms.Write4(ROMIO_SIOINTR);	//					; キー入力処理
 	roms.Write2(0x4e73);		//	rte
 
 	// NMI のハンドラ
