@@ -319,8 +319,8 @@ Luna88kPROMEmuDevice::Init()
 		roms.Write4(OP_cmp	(r2, r1, r2));
 		// 割り込みは sysclk, sio のみ許可しているので必ずどちらか。
 		roms.Write4(OP_bb1	(CMP_EQ, r2, (0x270 - roms.GetOffset()) / 4));
-	// key_intr:
-		roms.Write4(OP_ld	(r0, r5, (ROMIO_KEYIN - ROMIO_BASE)));
+	// sio_intr:
+		roms.Write4(OP_ld	(r0, r5, (ROMIO_SIOINTR - ROMIO_BASE)));
 
 	// _intr_ret:
 		// QUITSTOP があれば rte の戻り先をそっちに書き換える。
