@@ -63,15 +63,15 @@ class CGROMDevice : public ROMDevice
 	bool Init() override;
 };
 
-static inline CGROMDevice *GetCGROMDevice() {
+inline CGROMDevice *GetCGROMDevice() {
 	return Object::GetObject<CGROMDevice>(OBJ_CGROM);
 }
-static inline IPLROM0Device *GetIPLROM0Device() {
+inline IPLROM0Device *GetIPLROM0Device() {
 	return Object::GetObject<IPLROM0Device>(OBJ_IPLROM_BOOT);
 }
-static inline IPLROM1Device *GetIPLROM1Device() {
+inline IPLROM1Device *GetIPLROM1Device() {
 	return Object::GetObject<IPLROM1Device>(OBJ_IPLROM1);
 }
-static inline ROMDevice *GetIPLROM2Device() {
+inline ROMDevice *GetIPLROM2Device() {
 	return Object::GetObject<ROMDevice>(OBJ_IPLROM2);
 }
