@@ -479,6 +479,6 @@ class RTL8019ASDevice : public EthernetDevice, public IHWAddrFilter
 	static const char * const regnames[];
 };
 
-static inline RTL8019ASDevice *GetRTL8019ASDevice(int n) {
+inline RTL8019ASDevice *GetRTL8019ASDevice(int n) {
 	return Object::GetObject<RTL8019ASDevice>(OBJ_ETHERNET(n));
 }
