@@ -41,7 +41,7 @@ SCCDevice::SCCDevice()
 		mpscc.chan[0].dataaddr = 0xe98007;
 
 		// 5MHz
-		pclk_ns = 200_nsec;
+		pclk_tsec = 200_nsec;
 	} else {
 		// NWS-1750
 		mpscc.chan[0].desc = "Serial Port #0";
@@ -53,7 +53,7 @@ SCCDevice::SCCDevice()
 
 		// たぶん 4MHz
 		// http://www.ceres.dti.ne.jp/~tsutsui/netbsd/port-news68k.html#19990727
-		pclk_ns = 250_nsec;
+		pclk_tsec = 250_nsec;
 	}
 
 	monitor = gMonitorManager->Regist(ID_MONITOR_SCC, this);
@@ -1021,7 +1021,7 @@ SCCDevice::MonitorScreenCh(TextScreen& screen, int ch, int xbase, int ybase)
 void
 SCCDevice::SetXC(MPSCCChan& chan)
 {
-	chan.xc12_ns = (2 * (chan.tc + 2)) * pclk_ns * 12;
+	chan.xc12_tsec = (2 * (chan.tc + 2)) * pclk_tsec * 12;
 	ChangeBaudrate(chan);
 }
 
