@@ -56,7 +56,7 @@ SCSIDomain::SCSIDomain(IODevice *parent_, const char *config_name_)
 	config_name = config_name_;
 
 	monitor = gMonitorManager->Regist(ID_MONITOR_SCSIDEVS, this);
-	monitor->func = ToMonitorCallback(&SCSIDomain::MonitorUpdate);
+	monitor->SetCallback(&SCSIDomain::MonitorScreen);
 	// サイズは Create で決まる
 }
 
@@ -248,7 +248,7 @@ SCSIDomain::GetTargetCount() const
 // (どこでやるのがいいか分からんけど、SCSI デバイスを一括して表示したいので
 // とりあえずここで)
 void
-SCSIDomain::MonitorUpdate(Monitor *, TextScreen& screen)
+SCSIDomain::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	int y;
 
