@@ -55,7 +55,7 @@ class SysCtlrDevice : public InterruptDevice
 	// マスク設定レジスタの書き込み値から内部用マスクを作成
 	static uint32 MakeIntMask(uint32 data, uint n);
 
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	// CPU ごとのパラメータ
 	struct {
