@@ -68,6 +68,6 @@ class TVRAMDevice : public PlaneVRAMDevice
 	static const busdata wait;
 };
 
-static inline TVRAMDevice *GetTVRAMDevice() {
+inline TVRAMDevice *GetTVRAMDevice() {
 	return Object::GetObject<TVRAMDevice>(OBJ_PLANEVRAM);
 }
