@@ -22,7 +22,7 @@ class VirtIOEntropyDevice : public VirtIODevice
 	~VirtIOEntropyDevice() override;
 
  private:
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	// ディスクリプタを一つ処理する。
 	void ProcessDesc(VirtIOReq&) override;
