@@ -69,8 +69,6 @@ VM_LUNA1::VM_LUNA1()
 	gConfig->SetDefault("mpu-clock", 20);
 	// RAM 初期値は MAX にしておく
 	gConfig->SetDefault("ram-size", 16);
-	// SPC の入力クロック (おそらく 6.144MHz = 163ns が入ってる)
-	gConfig->Add("!spc-tCLF", 163);
 	// LUNA-I のクロック割り込みは 60Hz
 	gConfig->Add("!sysclk-freq", 60);
 
@@ -105,8 +103,6 @@ VM_LUNA88K::VM_LUNA88K()
 	gConfig->SetDefault("mpu-clock", 25);
 	// RAM 初期値は MAX にしておく
 	gConfig->SetDefault("ram-size", 64);
-	// SPC の入力クロック (XXX LUNA-I と同じ?)
-	gConfig->Add("!spc-tCLF", 163);
 	// LUNA-II, LUNA-88K, LUNA-88K2 のクロック割り込みは 100Hz らしい
 	gConfig->Add("!sysclk-freq", 100);
 
