@@ -35,8 +35,6 @@ VM_X68030::VM_X68030()
 	gConfig->SetDefault("mpu-clock", 25);
 	// RAM 初期値は MAX にしておく
 	gConfig->SetDefault("ram-size", 12);
-	// SPC の入力クロック (5MHz = 200ns)
-	gConfig->Add("!spc-tCLF", 200);
 
 	// デバイス
 	NEWDV(Power, new X68030PowerDevice());
