@@ -65,13 +65,13 @@ X68kIODevice::X68kIODevice()
 	: inherited(OBJ_X68KIO)
 {
 	map_monitor = gMonitorManager->Regist(ID_SUBWIN_X68KIO, this);
-	map_monitor->func = ToMonitorCallback(&X68kIODevice::MonitorUpdate);
+	map_monitor->SetCallback(&X68kIODevice::MonitorScreen);
 	map_monitor->SetSize(73, 1 + 32);
 	map_monitor->SetMaxHeight(1 + 256);
 
 	// エリアセットは実質ここが担当しているので、モニタもここ。
 	area_monitor = gMonitorManager->Regist(ID_MONITOR_AREASET, this);
-	area_monitor->func = ToMonitorCallback(&X68kIODevice::MonitorUpdateAreaset);
+	area_monitor->SetCallback(&X68kIODevice::MonitorScreenAreaset);
 	area_monitor->SetSize(32, 6);
 
 	cut_fc2 = (gConfig->Find("x68k-cut-fc2").AsInt() != 0);
@@ -334,7 +334,7 @@ X68kIODevice::Poke1(uint32 addr, uint32 data)
 }
 
 void
-X68kIODevice::MonitorUpdate(Monitor *, TextScreen& screen)
+X68kIODevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	screen.Clear();
 
@@ -477,7 +477,7 @@ X68kIODevice::SetExtarea(uint offset, uint8 data)
 
 // エリアセットと拡張エリアセットのモニタ。
 void
-X68kIODevice::MonitorUpdateAreaset(Monitor *, TextScreen& screen)
+X68kIODevice::MonitorScreenAreaset(Monitor *, TextScreen& screen)
 {
 	uint areaend;
 
