@@ -72,6 +72,6 @@ class XPRAMDevice : public IODevice
 	std::array<uint8, 512> ram {};
 };
 
-static inline XPbusDevice *GetXPbusDevice() {
+inline XPbusDevice *GetXPbusDevice() {
 	return Object::GetObject<XPbusDevice>(OBJ_XPBUS);
 }
