@@ -25,10 +25,13 @@ class WXButton : public WXTextPanel
 	~WXButton() override;
 
 	void FontChanged() override;
+	void Fit() override;
 
 	bool Enable(bool enable_) override;
 
  private:
+	void OnSize(wxSizeEvent&);
+
 	void OnMouse(wxMouseEvent& event);
 	void OnTimer(wxTimerEvent& event);
 
