@@ -20,8 +20,7 @@ WXCacheWindow::WXCacheWindow(wxWindow *parent, const wxString& name,
 	: inherited(parent, name, monitor_)
 {
 	// モニタパネルに送られるマウスイベントをこちらで処理する
-	monpanel->Connect(wxEVT_LEFT_DOWN,
-		wxMouseEventHandler(WXCacheWindow::OnLeftDown), NULL, this);
+	monpanel->Bind(wxEVT_LEFT_DOWN, &WXCacheWindow::OnLeftDown, this);
 }
 
 // デストラクタ
