@@ -9,7 +9,6 @@
 //
 
 #include "wxpagetablemonitor.h"
-#include "wxbitmappanel.h"
 #include "wxmainframe.h"
 #include "wxscrollbar.h"
 #include "wxtextscreen.h"
@@ -43,7 +42,6 @@ PageTable::PageTable(wxWindow *parent, int lv_, int width)
 	screen = new WXTextScreen(parent, nnSize(width, height));
 	vscroll = new WXScrollBar(parent, ID_SCROLL_0 + lv, wxSB_VERTICAL);
 	vscroll->SetScrollParam(0, height, height, height);
-	spacer = new WXBitmapPanel(parent, wxDefaultPosition, wxDefaultSize, 0);
 }
 
 // パラメータをクリアする。(インデックスとコントロールはそのまま)
@@ -81,6 +79,14 @@ PageTable::ViewTop() const
 	return vscroll->GetThumbPosition();
 }
 
+// このテーブルのコントロールの表示状態を制御する。
+void
+PageTable::Show(bool enable)
+{
+	screen->Show(enable);
+	vscroll->Show(enable);
+}
+
 
 //
 // ページテーブルウィンドウ (共通部分)
@@ -97,9 +103,9 @@ PageTable::ViewTop() const
 // | (TIA 情報)      | (TIB 情報)      |             |
 // +-----------------+-----------------+-------------+
 //
-// PageTable 内の段組み。
+// PageTable 内の段組み。空き地のところは下の bgpanel を見せる。
 // +--------+---------+
-// |        | spacer  |
+// |        | (空き地)|
 // | screen +---------+
 // |        | vscroll |
 // +--------+---------+
@@ -153,6 +159,9 @@ WXPageTableWindow::WXPageTableWindow(wxWindow *parent, const wxString& name)
 	ctrlpanel->SetSizer(ctrlbox);
 	ctrlbox->SetSizeHints(ctrlpanel);
 
+	// 表部分の下敷きパネル。
+	bgpanel = new WXTextPanel(this);
+
 	// モニタと同じ更新レートを適用。
 	auto mainframe = dynamic_cast<WXMainFrame *>(parent);
 	SetRate(mainframe->GetMonitorRate());
@@ -176,10 +185,10 @@ WXPageTableWindow::ConnectTableEvents()
 {
 	for (auto& t : table) {
 		// パネルで起きた LeftDClick, MouseWheel をこっちで受け取る。
-		t.screen->Connect(wxEVT_LEFT_DCLICK,
-			wxMouseEventHandler(WXPageTableWindow::OnLeftDClick), NULL, this);
-		t.screen->Connect(wxEVT_MOUSEWHEEL,
-			wxMouseEventHandler(WXPageTableWindow::OnMouseWheel), NULL, this);
+		t.screen->Bind(wxEVT_LEFT_DCLICK,
+			&WXPageTableWindow::OnLeftDClick, this);
+		t.screen->Bind(wxEVT_MOUSEWHEEL,
+			&WXPageTableWindow::OnMouseWheel, this);
 	}
 }
 
@@ -187,6 +196,7 @@ bool
 WXPageTableWindow::GetMySizeHints(wxSize *newp, wxSize *minp, wxSize *maxp,
 	wxSize *incp)
 {
+	int ctrl_minx = ctrlpanel->GetMinSize().x;
 	int ctrl_y = ctrlpanel->GetSize().y;
 #if 0
 	int stat_y = stat->GetSize().y;
@@ -200,13 +210,15 @@ WXPageTableWindow::GetMySizeHints(wxSize *newp, wxSize *minp, wxSize *maxp,
 	int min_y = table_y;
 	int max_y = table_y;
 
-	for (const auto& t : table) {
+	// テーブルがない場合でも、メッセージを表示するため
+	// 計算上1段分はあることにする。
+	for (int i = 0, end = table_count ?: 1; i < end; i++) {
+		const auto& t = table[i];
 		new_x += t.screen->GetSize().x;
 		new_x += t.vscroll->GetSize().x;
 	}
-	// テーブルがなければ死なない程度に適当な幅を用意。
-	if (new_x == 0) {
-		new_x = 200;
+	if (new_x < ctrl_minx) {
+		new_x = ctrl_minx;
 	}
 
 	new_y += table[0].screen->GetScreenHeight(32 + HEAD_ROW);
@@ -254,23 +266,42 @@ WXPageTableWindow::Layout()
 		stat->Hide();
 #endif
 
+		// 背景パネル。
+		// テーブル数が 0 だと無効メッセージの表示を兼ねる。
+		bgpanel->SetSize(0, table_y, client.x, table_h);
+		if (table_count == 0) {
+			bgpanel->DrawStringSJIS(UD_BLACK,
+				WXTextScreen::DefaultPadding, WXTextScreen::DefaultPadding,
+				"MMU TC Not Configured");
+		} else {
+			bgpanel->Fill();
+		}
+
 		int x = 0;
-		for (auto& t : table) {
+		int i;
+		for (i = 0; i < table_count; i++) {
+			auto& t = table[i];
+
 			int screen_w = t.screen->GetSize().x;
 			t.screen->SetSize(x, table_y, screen_w, table_h);
 			x += screen_w;
 
 			int vscroll_w = t.vscroll->GetSize().x;
 			// スクロールバーの上端を表の上端と揃える。
-			int spacer_h = t.screen->GetFontHeight() * HEAD_ROW
+			int head_h = t.screen->GetFontHeight() * HEAD_ROW
 				+ t.screen->GetPaddingTop();
-			t.spacer->SetSize(x, table_y, vscroll_w, spacer_h);
-			t.vscroll->SetSize(x, table_y + spacer_h,
-				vscroll_w, table_h - spacer_h);
+			t.vscroll->SetSize(x, table_y + head_h,
+				vscroll_w, table_h - head_h);
 			x += vscroll_w;
 
 			int thumbsize = std::min(t.count, t.screen->GetRow() - HEAD_ROW);
 			t.vscroll->SetScrollParam(thumbsize, t.count, thumbsize);
+
+			t.Show();
+		}
+		for (; i < table.size(); i++) {
+			auto& t = table[i];
+			t.Hide();
 		}
 
 		DoRefresh();
@@ -375,15 +406,15 @@ WXPageTable68030Window::Reconfig(uint32 new_tc_value)
 	// (E がオフで) TC の構成が無効なら出来ることは何もない。
 	m68030TC new_tc;
 	new_tc.Set(new_tc_value);
-	if (new_tc.Check() == false) {
+	if (new_tc.ConfigOK() == false) {
 		// 構成が無効。
 		tc_status = TC_NOT_CONFIG;
-		max_rows = 32;
+		max_rows = 8;
 		for (auto& t : table) {
 			t.Clear();
 			t.count = max_rows;
 		}
-		table[0].title = "MMU TC Not Configured";
+		table_count = 0;
 	} else {
 		if (new_tc.e) {
 			tc_status = TC_ENABLE;
@@ -394,10 +425,11 @@ WXPageTable68030Window::Reconfig(uint32 new_tc_value)
 		for (auto& t : table) {
 			t.Clear();
 		}
+		table_count = new_tc.termlv + 1;
 
 		int total_bits = new_tc.is;
 		max_rows = 0;
-		for (uint i = 0; i < countof(new_tc.tix) && new_tc.tix[i] != 0; i++) {
+		for (uint i = 0; i < table_count; i++) {
 			auto& t = table[i];
 
 			// ビット位置。
@@ -427,7 +459,7 @@ WXPageTable68030Window::Reconfig(uint32 new_tc_value)
 	}
 	radio_urp->SetLabel(_("User (CRP)"));
 
-	Layout();
+	Fit();
 }
 
 // 画面を更新して再描画する。
@@ -443,7 +475,8 @@ WXPageTable68030Window::DoRefresh()
 	for (auto& t : table) {
 		t.base = 0xffffffff;
 	}
-	if (tc_status == TC_ENABLE) {
+
+	if (tc_status != TC_NOT_CONFIG) {
 		if (mpu->mmu_tc.sre && show_urp == false) {
 			table[0].base = mpu->GetSRPl();
 		} else {
@@ -464,8 +497,10 @@ WXPageTable68030Window::DoRefresh()
 
 		auto& screen = t.screen->GetScreen();
 		screen.Clear();
-		screen.Puts(0, 0, (const char *)t.title.mb_str());
-		screen.Puts(1, 1, (const char *)t.head.mb_str());
+
+		TA attr_t = (tc_status == TC_DISABLE) ? TA::Disable : TA::Normal;
+		screen.Puts(0, 0, attr_t, (const char *)t.title.mb_str());
+		screen.Puts(1, 1, attr_t, (const char *)t.head.mb_str());
 		// 構成無効ならタイトルメッセージだけ表示。
 		if (tc_status == TC_NOT_CONFIG) {
 			continue;
@@ -482,9 +517,18 @@ WXPageTable68030Window::DoRefresh()
 				addr = t.GetAddr(i);
 				data = mainbus->Peek4(addr);
 			}
-			TA attr_i = TA::Normal;
-			TA attr_a = TA::Normal;
-			TA attr_v = TA::Normal;
+			TA attr_i;
+			TA attr_a;
+			TA attr_v;
+			if (__predict_true(tc_status == TC_ENABLE)) {
+				attr_i = TA::Normal;
+				attr_a = TA::Normal;
+				attr_v = TA::Normal;
+			} else {
+				attr_i = TA::Disable;
+				attr_a = TA::Disable;
+				attr_v = TA::Disable;
+			}
 			if (__predict_false(i == t.cursor)) {
 				attr_i = TA::Reverse;
 				attr_a = TA::Reverse;
@@ -555,7 +599,7 @@ WXPageTable68040Window::WXPageTable68040Window(wxWindow *parent,
 
 	// 最初に一度 MPU の現状を適用する。
 	// (以降はタイマー内で毎回チェックする)
-	Reconfig((uint32)mpu->mmu_tc->ps4k);
+	Reconfig(mpu->GetTC());
 
 	// ウィンドウサイズを確定させる。
 	FontChanged();
@@ -568,11 +612,24 @@ WXPageTable68040Window::~WXPageTable68040Window()
 
 // MMU の構成を適用する。
 void
-WXPageTable68040Window::Reconfig(uint32 new_ps4k)
+WXPageTable68040Window::Reconfig(uint32 new_tc_value)
 {
-	ps4k = (bool)new_ps4k;
+	tc_value = new_tc_value;
+
+	// 68040 の MMU に構成不能状態はない。
+	if ((new_tc_value & m68040TC::E)) {
+		tc_status = TC_ENABLE;
+	} else {
+		tc_status = TC_DISABLE;
+	}
+	if ((new_tc_value & m68040TC::P)) {
+		ps4k = false;
+	} else {
+		ps4k = true;
+	}
 
 	// 各テーブルの行数と見出し。
+	table_count = 3;
 	table[0].bitlen = 7;
 	table[1].bitlen = 7;
 	table[0].bitpos = 25;
@@ -608,7 +665,7 @@ WXPageTable68040Window::Reconfig(uint32 new_ps4k)
 		table[2].mask = ~0x1fff;
 	}
 
-	Layout();
+	Fit();
 }
 
 
@@ -624,8 +681,9 @@ void
 WXPageTable68040Window::DoRefresh()
 {
 	// MMU 構成に変更があれば再構築。
-	if (ps4k != mpu->mmu_tc->ps4k) {
-		Reconfig((uint32)mpu->mmu_tc->ps4k);
+	uint32 new_tc_value = mpu->GetTC();
+	if (tc_value != new_tc_value) {
+		Reconfig(new_tc_value);
 	}
 
 	table[1].base = 0xffffffff;
@@ -673,8 +731,11 @@ WXPageTable68040Window::DoRefresh()
 
 		auto& screen = t.screen->GetScreen();
 		screen.Clear();
-		screen.Puts(0, 0, (const char *)t.title.mb_str());
-		screen.Puts(1, 1, (const char *)t.head.mb_str());
+
+		TA attr_t = (tc_status == TC_DISABLE) ? TA::Disable : TA::Normal;
+		screen.Puts(0, 0, attr_t, (const char *)t.title.mb_str());
+		screen.Puts(1, 1, attr_t, (const char *)t.head.mb_str());
+
 		const int end = std::min(screen.GetRow(), t.count + HEAD_ROW);
 		for (uint y = HEAD_ROW, i = t.ViewTop(); y < end; y++, i++) {
 			uint32 addr;
@@ -686,9 +747,18 @@ WXPageTable68040Window::DoRefresh()
 				addr = t.GetAddr(i);
 				data = mainbus->Peek4(addr);
 			}
-			TA attr_i = TA::Normal;
-			TA attr_a = TA::Normal;
-			TA attr_v = TA::Normal;
+			TA attr_i;
+			TA attr_a;
+			TA attr_v;
+			if (__predict_true(tc_status == TC_ENABLE)) {
+				attr_i = TA::Normal;
+				attr_a = TA::Normal;
+				attr_v = TA::Normal;
+			} else {
+				attr_i = TA::Disable;
+				attr_a = TA::Disable;
+				attr_v = TA::Disable;
+			}
 			if (__predict_false(i == t.cursor)) {
 				attr_i = TA::Reverse;
 				attr_a = TA::Reverse;
