@@ -33,16 +33,38 @@ class WXSubWindow : public wxFrame
 		int style);
 	WXSubWindow(wxWindow *parent, wxWindowID id, const wxString& name)
 		: WXSubWindow(parent, id, name, DEFAULT_STYLE) { }
-	virtual ~WXSubWindow() override;
+	~WXSubWindow() override;
 
 	// フォントサイズ変更
 	virtual void FontChanged();
 
-	// コントロールからウィンドウサイズを設定する。
 	void Fit() override;
+	bool Layout() override;
+
+ protected:
+	// 自前レイアウト方式を使うことを宣言する。
+	void SetMyLayout();
+
+	// 自前レイアウト方式のサイズに関する情報を取得する。
+	virtual bool GetMySizeHints(wxSize *newsz, wxSize *minsz, wxSize *maxsz,
+		wxSize *incsz);
+
+	// 自前レイアウト。
+	// false を返したら子コントロールを配置してよい。
+	bool MyLayout();
+
+	// Sizer のためにオリジナルのほうのレイアウトを呼ぶ場合に使う。
+	bool BaseLayout() { return inherited::Layout(); }
 
  private:
 	void OnClose(wxCloseEvent& event);
 
+	wxSize DoMySizeHints();
+
+	// 自前レイアウト方式用。
+	bool my_layout {};			// 自前方式を使う場合は true
+	bool my_layout_pass2 {};	// 1パス目/2パス目の区別用。
+	wxSize prev_border {};		// 前回のウィンドウマネージャ装飾サイズ
+
 	wxDECLARE_EVENT_TABLE();
 };
